summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2026-05-22 12:46:15 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2026-05-23 19:18:53 -0700
commitd12e8a94f7042a8490f3e2e40726390d3b735f58 (patch)
tree5fc4846f8cb5b124b4a69ea2d918bf15ab4ebec1
parent19264b6912a111cfe426063ca431d202817f747d (diff)
Update src/alloc.c comments
-rw-r--r--src/alloc.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/alloc.c b/src/alloc.c
index 6a81fed2d69..1f4e5434e74 100644
--- a/src/alloc.c
+++ b/src/alloc.c
@@ -644,7 +644,7 @@ static_assert (MALLOC_IS_LISP_ALIGNED);
malloc_probe (size); \
} while (0)
/* Like malloc but check for no memory and block interrupt input. */
void *
xmalloc (size_t size)
@@ -686,7 +686,7 @@ xcalloc (size_t n, size_t s)
return val;
}
/* Like realloc but check for no memory and block interrupt input. */
void *
xrealloc (void *block, size_t size)
@@ -699,7 +699,7 @@ xrealloc (void *block, size_t size)
}
-/* Like free but block interrupt input. */
+/* Like free but do not free pdumper objects. */
void
xfree (void *block)
@@ -721,7 +721,7 @@ static_assert (INT_MAX <= PTRDIFF_MAX);
/* Allocate an array of NITEMS items, each of size ITEM_SIZE.
- Signal an error on memory exhaustion, and block interrupt input. */
+ Signal an error on memory exhaustion, and profile allocations. */
void *
xnmalloc (ptrdiff_t nitems, ptrdiff_t item_size)
@@ -735,7 +735,7 @@ xnmalloc (ptrdiff_t nitems, ptrdiff_t item_size)
/* Reallocate an array PA to make it of NITEMS items, each of size ITEM_SIZE.
- Signal an error on memory exhaustion, and block interrupt input. */
+ Signal an error on memory exhaustion, and profile allocations. */
void *
xnrealloc (void *pa, ptrdiff_t nitems, ptrdiff_t item_size)
@@ -761,7 +761,7 @@ xnrealloc (void *pa, ptrdiff_t nitems, ptrdiff_t item_size)
If PA is null, then allocate a new array instead of reallocating
the old one.
- Block interrupt input as needed. If memory exhaustion occurs, set
+ Profile memory allocations. If memory exhaustion occurs, set
*NITEMS to zero if PA is null, and signal an error (i.e., do not
return).
@@ -644,7 +644,7 @@ static_assert (MALLOC_IS_LISP_ALIGNED);
malloc_probe (size); \
} while (0)
-/* Like malloc but check for no memory and block interrupt input. */
+/* Like malloc but check for no memory, and profile allocations. */
void *
xmalloc (size_t size)
@@ -686,7 +686,7 @@ xcalloc (size_t n, size_t s)
return val;
}
-/* Like realloc but check for no memory and block interrupt input. */
+/* Like realloc but check for no memory, and profile allocations. */
void *
xrealloc (void *block, size_t size)